function phi=MixingZou2011(packing,dmin,dmax,Psi,Omega,A,rhop,grav,q,phi0,Bocri)
% Mixing model of Zou&Yu, 2011 
% INPUT: packing: 'loose' or 'dense'
%        dmin: min volume-equivalent diameters of distribution [m]
%        dmax: max volume-equivalent diameters of distribution [m]
%        Psi: sphericity 0..1
%        Omega: roundness 0..1
%        A: Hamaker constant [J]
%        rhop: "particle" density, i.e bulk density of boulders [kg/m]
%        grav: typical gravity [m/s]
%        q: binning factor (default 1.05)
%        phi0: manual setting of coarse monodisperse porosity of the particles as
%              they are (with given sphericity)
%        Bocri: Critical Bond number
%
% OUTPUT: phi: porosity
%

%
% Define parameters 
%

p=0.451; 
cdf_parameters=[dmin;dmax];

%
% Discretize
%

n=ceil(log(dmax/dmin)/log(q)); % number of bins

q=exp(log(dmax/dmin)/n); % new q, makes Xmin*q^n=Xmax excactly
dd=dmin*q.^(0:n);        % bin boundaries (n+1)
X=zeros(1,n);            % preallocation for speed
d=zeros(1,n);            % preallocation for speed
for i=1:n
    d(i)=exp((log(dd(i))+log(dd(i+1)))/2); % log mean size of the bin: "nominal diameter"
    X(i)=-cdf(dd(i+1),cdf_parameters)+cdf(dd(i),cdf_parameters); % volume (=mass) fraction in each bin
end

% now normalize such that sum(X)=1, 
X=X/sum(X);
% now reverse order for d and X, since d1>=d2>=...>=dn:
d=d(end:-1:1); X=X(n:-1:1);
% determine dcri (critical diameter), i.e. diameter when Bo=Bocri:
dcri=2*sqrt(1.1e17*A*Psi*Omega/rhop/grav/Bocri);


% Equivalent size ratios
R=ones(n,n); r=ones(n,n);
for j=2:n %  only values i<j are needed (triu matrix)
    for i=1:j-1
        R(i,j)=d(j)/d(i);
        x=xinterp(d,i,j,dcri); 
        r(i,j)=(1-x)*R(i,j)^p+x*R(i,j);
    end
end

% Interaction functions
f=zeros(n,n); g=zeros(n,n);
for j=2:n
    for i=1:j-1
        f(i,j)=(1-r(i,j))^3.33+2.81*r(i,j)*(1-r(i,j))^2.77;
        g(i,j)=(1-r(i,j))^1.97+0.36*r(i,j)*(1-r(i,j))^3.67;
    end
end

% calculate initial porosities according to Bond number and Psi
%
phii=zeros(1,n); %preallocation for speed
for i=1:n
    phii(i)=phi1(Bond(d(i)/2,A,grav,rhop,Psi,Omega),packing,Psi,phi0);
end
V=1./(1-phii); % initial specific volumes

% calculate VT vector
VT=zeros(1,n); % preallocation for speed
for i=1:n
    VT(i)=V(i)*X(i); % outside the summation...
    if i>1 % first summand
        for j=1:i-1
            VT(i)=VT(i) + (V(j)-(V(j)-1)*g(j,i))*X(j); 
        end
    end
    if i<n % second summand
        for j=i+1:n
            VT(i)=VT(i) + V(j)*(1-f(i,j))*X(j);
        end
    end
end
% calculate V, result from V=1/(1-phi)
Vmix=max(VT);
phi=1-1/Vmix;
end

function res=cdf(x,cdf_parameters)
    res=cdf_v_Ryugu(x,cdf_parameters(1),cdf_parameters(2)); 
end

function res=Bond(R,A,g,rhop,Psi,Omega) 
    res=1.1e17*A*Psi*Omega/rhop/g./R.^2; 
end

function res=phi1(Bo,packing,Psi,phi0) % "Initial porosity", i.e., 

m = 2.414; 
n = 0.1985;
res=phi0+(1-phi0)*exp(-m*Bo.^(-n)); 

end

function res=xinterp(d,i,j,dcri) 
if d(j)>=dcri
    res=1;
end
if d(i)<=dcri
    res=0;
end
if (d(j)<=dcri && dcri<=d(i)) % d(j)<=dcri<=d(i)
    res=1-1.543*exp(-0.697*d(i)/dcri);
end
end

function res=cdf_v_Ryugu(D,Dmin,Dmax) 
 
beta   = 0.09495;
lambda = 33.78;
logNT  = log(5.28e14);

g=@(x)exp(logNT-x.^(beta)/lambda^(beta)/(beta/3));

f=@(x)x.^3;
for i=1:length(D) 
    % partial integration:
    res(i)=f(D(i)).*g(D(i))-integral(@(x)3*g(x).*x.^2,0,D(i));
    % normalize to 1 at D>=Dmax:
    const=f(Dmax).*g(Dmax)-integral(@(x)3*g(x).*x.^2,0,Dmax);
    res(i)=res(i)/const; 
end
idx= D>Dmax;
res(idx)=1;
idx= D<Dmin;
res(idx)=0;

end
