function Plot_Fig2

% -------------------------------------------------------------------------
% Cumulative size frequency distributions as reported by Michikami et al.
% 2019. 
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Best Fit SFD
% -------------------------------------------------------------------------

Dmin = 0.02;
Dmax = 140;
D    = logspace(log10(Dmin),log10(Dmax),1000);

for i=1:length(D)
    SFD_fit_Weilbull(i) = Calculate_SFD_fit_Weilbull(D(i));
end

% -------------------------------------------------------------------------
% Power Law SFD
% -------------------------------------------------------------------------

SFD58     = Calculate_SFD_fit_Weilbull(5.8);
p         = 2.65;
C         = SFD58*5.8^p;
SFD_pow   = C*D.^(-p);

% -------------------------------------------------------------------------
% Load Data from Michikami
% -------------------------------------------------------------------------

%
% Add Errobars from the fitting
%

data = load('DataMichikami.mat','x','y','sy');
up   = exp(data.y+data.sy);
low  = exp(data.y-data.sy);
dat  = exp(data.y);
dia  = exp(data.x);

%
% Sort by size
%

[dia_s,ind] = sort(dia,'ascend');
up_s        = up(ind);
low_s       = low(ind);
dat_s       = dat(ind);

ind         = isnan(up_s);
dia_s(ind)  = [];
up_s(ind)   = [];
low_s(ind)  = [];
dat_s(ind)  = [];

% -------------------------------------------------------------------------
% Plot Results 
% -------------------------------------------------------------------------

figure(1)
clf
hold on
g = errorbar(dia_s,dat_s,dat_s-low_s,dat_s-up_s,[],[],'b.');
set(g,'capsize',0)
set(g,'marker','none')
set(g,'color',[0.8 0.8 0.8])
set(g,'linewidth',2)
h(1) = plot(D,SFD_fit_Weilbull,'k');
h(2) = plot(D,SFD_pow,'r');
hold off
set(h(1),'linewidth',1)
set(h(2),'linewidth',1)
set(gca,'fontsize',12)
set(gca,'xscale','log')
set(gca,'yscale','log')
grid on
box on
xlabel('Diameter [m]')
ylabel('N(>D) [km^{-2}]')
h = legend([h(1) h(2) g],[{'Weibull'} {'Power Law'} {'Data incl. Uncert.'}],'location','ne');
set(h,'fontsize',10)
ylim([1e-2 1e10])
xlim([Dmin/2,1e3])

% -------------------------------------------------------------------------
% Convert N(>D) to V(<D) for the fit function
% -------------------------------------------------------------------------

VFD_fit = Calculate_VFD_fit(SFD_fit_Weilbull,D);

% -------------------------------------------------------------------------
% Convert N(>D) to V(<D) for the Power law
% -------------------------------------------------------------------------

p = 2.65;
VFD_pow = Calculate_VFD_pow(p,D);

% -------------------------------------------------------------------------
% Plot Volume Frequency Distributions
% -------------------------------------------------------------------------

figure(2)
clf
h(1) = plot(D,VFD_fit/VFD_fit(end),'k');
hold on
h(2) = plot(D,VFD_pow/VFD_pow(end),'r');
hold off
set(h(1),'linewidth',1)
set(h(2),'linewidth',1)
set(gca,'fontsize',12)
set(gca,'xscale','log')
set(gca,'yscale','log')
grid on
xlim([Dmin/2,1e3])
xlabel('Diameter [m]')
ylabel('V(<D)')
h = legend('Weibull','Power Law','location','se');
set(h,'fontsize',10)

end

function SFD_fit = Calculate_SFD_fit_Weilbull(D)
%
% Calculate the size freqeuency distribution as a function of diameter D
% 
% INPUT: D  : Diameter array, length n
%
% V1.0 M.Grott, 2.8.2019
%

NT = 5.28e14;
beta = 0.09495;
lamda = 33.78;
SFD_fit = NT*exp(-3*(D/lamda)^beta/beta);

end

function VFD = Calculate_VFD_pow(p,D) 
%
% Calculate the volume distribution from the size distribution
% Use for power law distributions.
% 
% INPUT: p  : Power Law index
%        D  : Diameter array, length n
%
% V1.0 M.Grott, 2.8.2019
%

VFD = D(1)^p*p/(3-p)*(D.^(3-p)-D(1)^(3-p));
      
end

function VFD = Calculate_VFD_fit(SFD,D) 
%
% Calculate the volume distribution from the size distribution
% Use for empirically fitted data. 
% 
% INPUT: SFD: Frequency distribution array, N(>D), length n
%        D  : Diameter array, length n
%
% V1.0 M.Grott, 2.8.2019
%

kernel = 3*SFD.*D.^2;
Nmax   = SFD(1);
for i=1:length(D)
    VFD(i)  = Nmax*D(1)^3-SFD(i)*D(i)^3+trapz(D(1:i),kernel(1:i),2);    
end

       
end

